﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                try
                {
                    $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
                }
                catch
                {

                }
            }
        }
    }
}
# SIG # Begin signature block
# MIIpKwYJKoZIhvcNAQcCoIIpHDCCKRgCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCB5mT/HBF+ApGFF
# NurlQsK+/gKFs6a98ziX+/GaLDsVJqCCDfQwggZyMIIEWqADAgECAhMzAAAEPxXT
# o2me74nMAAAAAAQ/MA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQxMTE5MTk1MDU4WhcNMjUxMTEyMTk1MDU4WjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAqsr+k9yh9dU/cF9B1Ko8
# T6SaoJNg9kJYh809q0GBZq1WrDbRGcgAClcMmMtAFgIps7Fimyyw/ympDR2Zila5
# iDwHRPpPefdumtlFE2iLDgoZHDXoOs2DdZZza5tYKaA8rmq8vmIh6JfvXHqtlWJd
# s6hAxzHrimvJHUF+Kq5T8n8bRbzOUHbfrvvIYDlQ5YXu1tCFU9mEcVe0y+A3VgsZ
# gEobuJ8UB64Snm0P3eJRNYMELzuNZuwRK+X3VF87u4VRM7t18/csk7ANACbO8/nC
# tT5NzsAdobodUQoSevvY8b474GO9QdMFjXN6PF7oxGq0fT617VN0Nizkl4qAVa9c
# qBhplDelQ20xjzOnFTpHhp9j7/9neYBYkonH9EnLWkIHfCQ7NlDT6vSVyD/tswb9
# jQK7jj5klCrPx9UL3/T7zWCBGbNGp7ylExVt4crtI42CVGC7YpH/IEO2CeCszVVy
# HslZxycPBmRRGBzvLwodkYTl9HnsDMVjnlucqsbWNeqdAgMBAAGjggGCMIIBfjAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQULPGeoivj
# /NcRbrh1VDqlXOI1df0wVAYDVR0RBE0wS6RJMEcxLTArBgNVBAsTJE1pY3Jvc29m
# dCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEWMBQGA1UEBRMNNDY0MjIzKzUw
# MzM5MjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBL
# MEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWND
# b2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggr
# BgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
# aWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJ
# KoZIhvcNAQEMBQADggIBAKiH9gTsKkb1QsFOWaiSF1sUpJ/aboTO7pn5eafSaeup
# pt9KVvZaZbZOonaTWyfR9k4M/WPBsyRaIQRDvEhlB1JCcSHUe3TxFdYMyA0ZLLGV
# uUahdJ7KiNo0HrFtQbhtIo/SwcoezS06kShkDx4/PMlSdsp/woebzjuab7sgvSXy
# sX97vj1ZQlESvgldF2wAg5+C0wKCLdB43/H08gq53PcZQ2s5qDvqluZ0tFjNmPEH
# Kh+kaG+xTZCRJQGf/mrTmBlRtKcL293EXNtEO344ybYNoCO7snEI5Ine3vjJgd66
# J7HJqrSYPiKjEZ1KH85n8A6ivR4LlsL87gqrr41NPR6mN3KA3lqWd2jpnS0I7T8W
# Nqk1k9aQQlXHQ8V+TRwvXdDlh5OdIEQ/xrR21yV+lDGjkWsyjeX2UgOg0wFDcX90
# PVPGXP8DPvZb04P38npzWrfKwmyQC3gCA91dfXOg6g9AmUJKZvQbdcEcoZhLw9dt
# 6MM2149eeaz6QIprT6marM21TGXp40N/v/5MXeAk/7LySCHUJWiaIt9lfyOtKdDT
# hSNPFTuXcINaDJOBcY21ranmTsLd/3FKw+Z5UpvxHA83W0qRBq6t5I/C5AKrQZho
# mPyA7QyVsDHs3ekXXZQ11v203ACerQ2KnquSR7gE25yfcz3vF1VV4IA/7HKts8dy
# MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9z
# b2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1
# OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
# MDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqC
# EE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC
# 04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlIm
# Ei/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPe
# Bw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb
# 2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
# OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yx
# kq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA
# 4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uD
# jexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ec
# XL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4Ta
# sIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQD
# AgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIE
# DB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNV
# HSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklo
# dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
# BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQB
# gjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBn
# AGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqG
# SIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8u
# LD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxC
# i1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQ
# u6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n
# 7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVY
# ODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
# bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3
# BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmA
# H9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5
# GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF6
# 70EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGC
# Go0wghqJAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMA
# AAQ/FdOjaZ7vicwAAAAABD8wDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkD
# MQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJ
# KoZIhvcNAQkEMSIEILtEeMEUesXcycnvAB00C1m+1XkEcUBjfhNIN2IZgfkZMEIG
# CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEBBQAEggGAULzdp5VrWNT8rTbj
# hwMJm2a+w40eug68HQCMsdaHPLOCwGkIIwraAt08Y8QETBro/I6GuNe2tYsdBYad
# e4+Dq/GS8w9eAhI2M8dBiqes8NncSxYQzFCJDq/Q+/mFE5JowphFb8UOaflcoDsk
# 9guNZlqPc8T7Tde/d5X0us5ZJ7zY+SeIpqwEwqlkP5HkzT9TFDSNVWmSMLLm8BMz
# ghxeysWsZW3+p7WGcGd/eF39Pk8xY5XRX6SRBqgjdzbTn2eFkRQPRmUrGnAn5uaA
# /ROuwFcDevWGmWT1PSV26kMOZs1E9tJYNYy+vnM6f56vdLuYGwtcG96g+/2hCvYy
# /ioNpmDroBo+3oygfiVf6WPnYgAn141Nu8ZYZOXz+rK9Cy3zIUyUqEUd0GQjFHQv
# uwLeRwqwRt6XabZkPD4F1qnJPAzth2VSnC3Vz6ApTXUti9p94NOgaZD9Et054mij
# zv3nBqxejItxHkQqtQHTQPPcWFjGshZ/kWhl1uE6BUTTvGPfoYIXlzCCF5MGCisG
# AQQBgjcDAwExgheDMIIXfwYJKoZIhvcNAQcCoIIXcDCCF2wCAQMxDzANBglghkgB
# ZQMEAgEFADCCAVIGCyqGSIb3DQEJEAEEoIIBQQSCAT0wggE5AgEBBgorBgEEAYRZ
# CgMBMDEwDQYJYIZIAWUDBAIBBQAEIBo6rZ+ZAgGGk2RXueZ24Cs4Xlwfnw6UaRLH
# 88usDd9OAgZnt6lHPqEYEzIwMjUwMzA2MDM1NjE3LjM2NVowBIACAfSggdGkgc4w
# gcsxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsT
# HE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJzAlBgNVBAsTHm5TaGllbGQg
# VFNTIEVTTjo4OTAwLTA1RTAtRDk0NzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUt
# U3RhbXAgU2VydmljZaCCEe0wggcgMIIFCKADAgECAhMzAAACDizLKH2VIHVjAAEA
# AAIOMA0GCSqGSIb3DQEBCwUAMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEw
# MB4XDTI1MDEzMDE5NDMwM1oXDTI2MDQyMjE5NDMwM1owgcsxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVy
# aWNhIE9wZXJhdGlvbnMxJzAlBgNVBAsTHm5TaGllbGQgVFNTIEVTTjo4OTAwLTA1
# RTAtRDk0NzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCC
# AiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAKzm3uJG1e3SFt6j0wTvxliM
# ijexpC5YwEVDtfiz2+ihhEAFM5/amhMdq3H4TCcFQYHVXa38TozCxA2Zjlekz/vl
# oKtl3ECetX2jhO7mwF6ltt96Gys5ZEEgagkTo+1ah3UKsV6GbV2LPeNjcfyIWuHu
# ep5+eJnVKdtxY8zI0jG4YXOlCIMD4TlhLfeZ4yppfCF1vTUKW7KaH/cQq+SePh0i
# lBkRY48zePFtFUBg3kna06tiQlx0PHSXTZX81h3WqS9QGA/Gsq+KrmTPsToBs6J8
# INIwGByf9ftFDDrfRCTOqGnSQNTap6L9qj0gea65F5cSOeOmBOyvgBvfcgIAoxjE
# 5B76fnCoRVwT05PKGZZklLkCdZROeKiTiaDA40FZDUMs4YWRnBdPffgg8Kp3j/f8
# t38i2LOKy3JRliyaX8LhmF0Atu99jDO/fU7F/w1OZXkgbFZ0eeTYeGHhufNMqiwR
# oOsm9AyJD6WiiMzt/luB3IEGdhAGbn7+ImzHDyTbbvMXaNs0j47Czwct5ka3y3q4
# nZ5WM0PUHRi2CwE/RywGWecj7j528thG3RwCrDo+JhLPkVJlxumLTF0Af+N3d3PI
# YCtvIu6jr0e6B8YQRv+wzTutyg/Wjdxnx5Yxvj4wgHx645vkNU8OcRwWLg0O6Rgz
# 3WDUO3+oh6T6u0TzxVLxAgMBAAGjggFJMIIBRTAdBgNVHQ4EFgQUhXFEaVIRkT7U
# RIrpQYjtg1wQiNswHwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXSZacbUzUZ6XIwXwYD
# VR0fBFgwVjBUoFKgUIZOaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9j
# cmwvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3JsMGwG
# CCsGAQUFBwEBBGAwXjBcBggrBgEFBQcwAoZQaHR0cDovL3d3dy5taWNyb3NvZnQu
# Y29tL3BraW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIw
# MjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcD
# CDAOBgNVHQ8BAf8EBAMCB4AwDQYJKoZIhvcNAQELBQADggIBAHXgvZMv4vw5cvGc
# ZJqXaHfSZnsWwEWiiJiRRU5jTkX2mfA9NW58QMZYSk03LY59pQdYg6hD/3+uPA7S
# FLZKkHQHMwCTaDLP3Y0ZY6lZukF0y+utEOmJZmL+4tLhkZ1Gfc/YNxxiaWQ0/69p
# EBe+e/6anbsqAjv2Yn2EbIJBu+0wiORtiguoruwXtZqGf2suNfXLlAkviW8TLdCY
# D0pEGPnpwS/+UC/MOrt5KKpGr+kLKrJzy7OZDxJ4pbJa7oONQD2+LzhCyYuOo8YK
# cfhw/KD633lGlb7veyeF7DWIJX7Be7ZHEydaDsSwPl4uQkcuzNQg935cKUP4VO9X
# TcZ+sMN+T7jl+Uf94pFlzcxRm2eEsmM/C/cqgoNJxbiJXpJsJHJxg+SqhYGsd/tK
# 8MDsasfZQ63PVZrWTbux1mCkbr9z0KoojwJfm+Bpr4DuhgdvhkGPtLy7yyDHBYrs
# eBYNEHI4fcKIm7gsnyHdOJGRECuYdGnSVs1/WIAq4vzzogoT3Xa/TKrnm3yMzGMF
# Tu6guythUigqTOH6wCSCSkY6hkvXj52XFUz3UFq/NriQ4NNSXDNv5KlexKpXHye4
# HqqFTLumqmDDDWrhI2EDEWcXGzGJOVqgvvkY3E9HrTmUnZZd6G0SLv/5h8mq8f6+
# epymoKPJD2E1pXO44QdfgzK6pyPCMIIHcTCCBVmgAwIBAgITMwAAABXF52ueAptJ
# mQAAAAAAFTANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNh
# dGUgQXV0aG9yaXR5IDIwMTAwHhcNMjEwOTMwMTgyMjI1WhcNMzAwOTMwMTgzMjI1
# WjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
# UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQD
# Ex1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCCAiIwDQYJKoZIhvcNAQEB
# BQADggIPADCCAgoCggIBAOThpkzntHIhC3miy9ckeb0O1YLT/e6cBwfSqWxOdcjK
# NVf2AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+uDZnhUYjDLWNE893MsAQGOhg
# fWpSg0S3po5GawcU88V29YZQ3MFEyHFcUTE3oAo4bo3t1w/YJlN8OWECesSq/XJp
# rx2rrPY2vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxqD89d9P6OU8/W7IVWTe/d
# vI2k45GPsjksUZzpcGkNyjYtcI4xyDUoveO0hyTD4MmPfrVUj9z6BVWYbWg7mka9
# 7aSueik3rMvrg0XnRm7KMtXAhjBcTyziYrLNueKNiOSWrAFKu75xqRdbZ2De+JKR
# Hh09/SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZnkXftnIv231fgLrbqn427DZM9itu
# qBJR6L8FA6PRc6ZNN3SUHDSCD/AQ8rdHGO2n6Jl8P0zbr17C89XYcz1DTsEzOUyO
# ArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMYctenIPDC+hIK12NvDMk2ZItb
# oKaDIV1fMHSRlJTYuVD5C4lh8zYGNRiER9vcG9H9stQcxWv2XFJRXRLbJbqvUAV6
# bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtFtvUeh17aj54WcmnGrnu3tz5q4i6t
# AgMBAAGjggHdMIIB2TASBgkrBgEEAYI3FQEEBQIDAQABMCMGCSsGAQQBgjcVAgQW
# BBQqp1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4EFgQUn6cVXQBeYl2D9OXSZacb
# UzUZ6XIwXAYDVR0gBFUwUzBRBgwrBgEEAYI3TIN9AQEwQTA/BggrBgEFBQcCARYz
# aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9Eb2NzL1JlcG9zaXRvcnku
# aHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMIMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIA
# QwBBMAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2
# VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwu
# bWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEw
# LTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0dHA6Ly93
# d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYt
# MjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3hLB9nATEkW+Geckv8qW/q
# XBS2Pk5HZHixBpOXPTEztTnXwnE2P9pkbHzQdTltuw8x5MKP+2zRoZQYIu7pZmc6
# U03dmLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99qb74py27YP0h1AdkY3m2CDPVt
# I1TkeFN1JFe53Z/zjj3G82jfZfakVqr3lbYoVSfQJL1AoL8ZthISEV09J+BAljis
# 9/kpicO8F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbCHcNhcy4sa3tuPywJeBTp
# kbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6MhrZlvSP9pEB9s7GdP32THJvEKt1MMU0
# sHrYUP4KWN1APMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNtyo4JvbMBV0lUZNlz138e
# W0QBjloZkWsNn6Qo3GcZKCS6OEuabvshVGtqRRFHqfG3rsjoiV5PndLQTHa1V1QJ
# sWkBRH58oWFsc/4Ku+xBZj1p/cvBQUl+fpO+y/g75LcVv7TOPqUxUYS8vwLBgqJ7
# Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr4A245oyZ1uEi6vAnQj0llOZ0
# dFtq0Z4+7X6gMTN9vMvpe784cETRkPHIqzqKOghif9lwY1NNje6CbaUFEMFxBmoQ
# tB1VM1izoXBm8qGCA1AwggI4AgEBMIH5oYHRpIHOMIHLMQswCQYDVQQGEwJVUzET
# MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
# TWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmlj
# YSBPcGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046ODkwMC0wNUUw
# LUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2WiIwoB
# ATAHBgUrDgMCGgMVAErodj9lYuc5wwRCyOQMCgH8llYIoIGDMIGApH4wfDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9z
# b2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwDQYJKoZIhvcNAQELBQACBQDrc0p1MCIY
# DzIwMjUwMzA1MjIxMTAxWhgPMjAyNTAzMDYyMjExMDFaMHcwPQYKKwYBBAGEWQoE
# ATEvMC0wCgIFAOtzSnUCAQAwCgIBAAICDVcCAf8wBwIBAAICE4UwCgIFAOt0m/UC
# AQAwNgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYBBAGEWQoDAqAKMAgCAQACAwehIKEK
# MAgCAQACAwGGoDANBgkqhkiG9w0BAQsFAAOCAQEAsKiP5v6yIxIvATAj93nZ3Gpb
# 5YFfPYkEfA+R39uCS8mxFRbxJS5SUqNtAxkqFJumd/wpKdRelw2EqGawioRi049S
# Nva9/FXa+8FLLZ0LL3KNm1hMXRiMeRVNzC/UpF7N2ocoMCgmDRl7oVMHN7XDumUg
# Oz2oLzGK1Pw47sleqgZqUBiTTTtSbxF8dMim5SKmMLFjNdmwgzLVl8iAthPwN+EX
# omOZs0QfGXvLuYm7FoC1bPZFvsfJL3v+1Un/RufRs1s6So8bfR1q0nPpu9C/tOpK
# yv1A0yKF5GkgxGpK9JG8Lq8ho+mcRcxALxEEfoRvNYx6en0HijUSw4mzkY7ZXjGC
# BA0wggQJAgEBMIGTMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwAhMzAAAC
# DizLKH2VIHVjAAEAAAIOMA0GCWCGSAFlAwQCAQUAoIIBSjAaBgkqhkiG9w0BCQMx
# DQYLKoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkEMSIEIPXy3ILrB/ienwn6QfaF2D/D
# 4hbdMckneMqINv6gdD7xMIH6BgsqhkiG9w0BCRACLzGB6jCB5zCB5DCBvQQgAXQd
# cyXw6YGQrbrubGhspKKHA50/R5Q1dAzKk/NPEoYwgZgwgYCkfjB8MQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
# A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQg
# VGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAg4syyh9lSB1YwABAAACDjAiBCCF4tDb
# AgBu9XHO771ZHMzyleuubjZkPhKQddAUo7bb1DANBgkqhkiG9w0BAQsFAASCAgAO
# VtasUBbuQkVXBYn5So7u+8sIq315RuwH/NSZuQ5l5fG6AZzrrjzdLXZa77XlW958
# bhkWT3YMBLBD2nPO8FC/XkHZskG7hQ4BuZ4V2qOrEdflGg2Miw7w6Cuwo6o10e+6
# faXQ/ke9Ze2nSs3RgohE/CiZA9FKFIL8dgLHLgdLk+ExLtpFLRIzCHppzQRxtIax
# 9LE3sDI30FGVLTc4Lj+NSO49hXFvH5B2UIa87nM9IotIvXsRn60GgZtwSGw3mfMM
# ODmedxuTjF9JmFn/JjhwSaAHH7Wa1454S8ZhnaASzhPyqUMLd2ILneCLW+v2mM9L
# /rwXfJaM81DoaeSO8RgYW7444ClgzOP6d3+39m4mCLtoSPlx5HWMCvecsFoE5V8v
# DRNDOqm4PYI9ckICqQY5VcNBVxKf1d72TSr1RmOvTa19bZLZDJf1SX9jOpuyOJ3p
# AK4ps0JLgS6VO+t2tPMnBbDZh6DQ4DZjrLPeQROymCUfVQcU3Kh/fR7KUaNPoh99
# 1W2ReXVuY1DLw5v91plheEHMNVJP0xaYOiGbLMLLoJM537KFrYzfW7Jt4IGS1D2E
# si5XYJoFuEiQLlPmnjt1c5Qi0Ln/DJpXRxYiwrU1UJhQ8BARmOYP7NB1QvjtHSo9
# MYxoxLXzbSnFjvQ2GqB06LXYnGkRlyUUXLSibtvVCA==
# SIG # End signature block
